@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include <QUrl>
 
 class WebView;
 
@@ -22,6 +23,9 @@ class MainWindow : public QMainWindow {
 
     private:
         WebView *m_webView;
+#ifdef Q_WS_MAEMO_5
+        QUrl m_url;
+#endif
 };
 
 #endif // MAINWINDOW_H
